import {queryRenderResults} from './nopaque.listenerCallbacks.js'

/**
 * Recieves a corpus analysis session via socket.io.
 * Closes the loading modal that has been opend with requestSession at the
 * start of the request.
 */
function recieveSession(client) {
  client.socket.on('corpus_analysis_init', (response) => {
    console.group('recieve session')
    console.info('corpus_analysis_init: Client recieving session/or error',
                 'codes via socket.on');
    if (response.code === 200) {
      console.info('corpus_analysis_init: Initialization succeeded');
      console.info(response);
      console.groupEnd();
      if (client.displays.init != undefined) {
        client.displays.init.element.M_Modal.close();
        client.displays.init.setVisibilityByStatus('success');
      }
    } else {
      let errorText = `Error ${response.code} - ${response.msg}`;
      if (client.displays.init.errorContainer != undefined)  {
        client.displays.init.errorContainer.innerHTML = `<p class="red-text">`
          + `<i class="material-icons tiny">error</i>${errorText}</p>`;
      }
      if (client.displays.init != undefined)  {
        client.displays.init.setVisibilityByStatus('error');
      }
      console.error(`corpus_analysis_init: ${errorText}`);
    }
  });
}

/**
 * Recieves the query process status before any actual results are being
 * transmitted. So it recieves error codes if a query failed or
 * was invalid etc.
 * Also prepares the result.jsList for the incoming data.
 */
function recieveQueryStatus(client) {
  client.socket.on('corpus_analysis_query', (response) => {
    console.group('corpus_analysis_query: Client recieving query process',
                 'status via socket.on');
    client.results.clearAll();
    console.info(response);
    console.groupEnd();
  });
}

/**
 * Recieves the query data from the request and handles it.
 */
function recieveQueryData(client) {
  client.socket.on('corpus_analysis_query_results', (response) => {
    console.group('corpus_analysis_query_results: Client recieving query',
                  'data via socket.on');
    console.info('Recieved chunk', response);
    queryRenderResults(response.payload, client);
    console.info('Added chunk data to results.data and rendered it with',
                 'results.jsList')
    console.groupEnd();
  });
}

// export listeners from this module
export { recieveSession, recieveQueryStatus, recieveQueryData };